@@ -1,20 +1,8 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
   code based on calligra autocorrection.
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "autocorrection.h"
@@ -36,18 +24,6 @@
 using namespace PimCommon;
 
 AutoCorrection::AutoCorrection()
-    : mSingleSpaces(true)
-    , mUppercaseFirstCharOfSentence(false)
-    , mFixTwoUppercaseChars(false)
-    , mAutoFractions(true)
-    , mCapitalizeWeekDays(false)
-    , mReplaceDoubleQuotes(false)
-    , mReplaceSingleQuotes(false)
-    , mEnabled(false)
-    , mSuperScriptAppendix(false)
-    , mAddNonBreakingSpace(false)
-    , mMaxFindStringLenght(0)
-    , mMinFindStringLenght(0)
 {
     mNonBreakingSpace = QChar(QChar::Nbsp);
     // default double quote open 0x201c
@@ -919,6 +895,9 @@ int AutoCorrection::advancedAutocorrect()
             if (pos == -1) {
                 pos = actualWordWithFirstUpperCase.lastIndexOf(i.key());
             }
+            if (pos == -1) {
+                continue;
+            }
             QString replacement = i.value();
 
             // Keep capitalized words capitalized.
