@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "autocorrection_gui.h"
@@ -23,8 +12,6 @@
 
 #include "pimcommon_debug.h"
 
-#include <KSharedConfig>
-
 #include <QPointer>
 #include <QVBoxLayout>
 #include <QPushButton>
@@ -39,7 +26,7 @@ ConfigureTestDialog::ConfigureTestDialog(PimCommon::AutoCorrection *autoCorrecti
     : QDialog(parent)
 {
     setWindowTitle(QStringLiteral("Configure Autocorrection"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -99,14 +86,14 @@ void TextEditAutoCorrectionWidget::keyPressEvent(QKeyEvent *e)
 
 AutocorrectionTestWidget::AutocorrectionTestWidget(QWidget *parent)
     : QWidget(parent)
+    , mConfig(KSharedConfig::openConfig(QStringLiteral("autocorrectionguirc")))
 {
-    mConfig = KSharedConfig::openConfig(QStringLiteral("autocorrectionguirc"));
     PimCommon::PimCommonSettings::self()->setSharedConfig(mConfig);
     PimCommon::PimCommonSettings::self()->load();
 
     mAutoCorrection = new PimCommon::AutoCorrection;
-    QVBoxLayout *lay = new QVBoxLayout(this);
-    QToolBar *bar = new QToolBar;
+    auto *lay = new QVBoxLayout(this);
+    auto *bar = new QToolBar;
     lay->addWidget(bar);
     bar->addAction(QStringLiteral("Configure..."), this, &AutocorrectionTestWidget::slotConfigure);
     QAction *richText = new QAction(QStringLiteral("HTML mode"), this);
@@ -151,7 +138,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    AutocorrectionTestWidget *w = new AutocorrectionTestWidget();
+    auto *w = new AutocorrectionTestWidget();
     w->resize(800, 600);
 
     w->show();
