@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "configurepluginslistwidget.h"
@@ -32,7 +20,7 @@ using namespace PimCommon;
 ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -68,7 +56,7 @@ void ConfigurePluginsListWidget::slotItemChanged(QTreeWidgetItem *item, int colu
 void ConfigurePluginsListWidget::slotItemSelectionChanged()
 {
     QTreeWidgetItem *item = mListWidget->currentItem();
-    if (PluginItem *pluginItem = dynamic_cast<PluginItem *>(item)) {
+    if (auto *pluginItem = dynamic_cast<PluginItem *>(item)) {
         Q_EMIT descriptionChanged(pluginItem->mDescription);
     }
 }
@@ -123,11 +111,11 @@ void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUti
 {
     itemsList.clear();
     if (!lst.isEmpty()) {
-        QTreeWidgetItem *topLevel = new QTreeWidgetItem(mListWidget, QStringList() << topLevelItemName);
+        QTreeWidgetItem *topLevel = new QTreeWidgetItem(mListWidget, {topLevelItemName});
         topLevel->setFlags(topLevel->flags() & ~Qt::ItemIsSelectable);
         const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(groupName, prefixKey);
         for (const PimCommon::PluginUtilData &data : lst) {
-            PluginItem *subItem = new PluginItem(topLevel);
+            auto *subItem = new PluginItem(topLevel);
             subItem->setText(0, data.mName);
             subItem->mIdentifier = data.mIdentifier;
             subItem->mDescription = data.mDescription;
@@ -139,8 +127,8 @@ void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUti
                 subItem->setCheckState(0, isPluginActivated ? Qt::Checked : Qt::Unchecked);
             }
             if (data.mHasConfigureDialog) {
-                QToolButton *but = new QToolButton(mListWidget);
-                QAction *act = new QAction(but);
+                auto *but = new QToolButton(mListWidget);
+                auto *act = new QAction(but);
                 const QStringList actData {
                     configureGroupName, data.mIdentifier
                 };
