@@ -1,19 +1,7 @@
 /*
-  Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "logactivitiesdialog.h"
@@ -34,8 +22,8 @@ using namespace PimCommon;
 LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Log activities"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    setWindowTitle(i18nc("@title:window", "Log activities"));
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
 
     mLogWidget = new LogActivitiesWidget(this);
@@ -58,7 +46,7 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     mSaveButton->setObjectName(QStringLiteral("savebutton"));
     mSaveButton->setEnabled(false);
 
-    LogactivitiesPurposeMenuWidget *purposeMenu = new LogactivitiesPurposeMenuWidget(this, this);
+    auto *purposeMenu = new LogactivitiesPurposeMenuWidget(this, this);
     mShareButton = new QPushButton(i18n("Share..."), this);
     mShareButton->setMenu(purposeMenu->menu());
     mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
