@@ -2,34 +2,11 @@
     simplestringlisteditor.cpp
 
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2001 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "simplestringlisteditor.h"
@@ -77,8 +54,8 @@ public:
     QPushButton *mDownButton = nullptr;
     QPushButton *mCustomButton = nullptr;
     QVBoxLayout *mButtonLayout = nullptr;
-    QString mAddDialogLabel;
-    QString mRemoveDialogLabel;
+    QString mAddDialogLabel = i18n("New entry:");
+    QString mRemoveDialogLabel = i18n("Do you want to remove selected text?");
 };
 
 SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode buttons, const QString &addLabel, const QString &removeLabel, const QString &modifyLabel, const QString &addDialogLabel)
@@ -87,7 +64,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
 {
     setAddDialogLabel(addDialogLabel);
     setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-    QHBoxLayout *hlay = new QHBoxLayout(this);
+    auto *hlay = new QHBoxLayout(this);
     hlay->setContentsMargins(0, 0, 0, 0);
 
     d->mListBox = new QListWidget(this);
@@ -366,12 +343,12 @@ void SimpleStringListEditor::slotModify()
 
 void SimpleStringListEditor::setRemoveDialogLabel(const QString &removeDialogLabel)
 {
-    d->mRemoveDialogLabel = removeDialogLabel.isEmpty() ? i18n("Do you want to remove selected text?") : removeDialogLabel;
+    d->mRemoveDialogLabel = removeDialogLabel;
 }
 
 void SimpleStringListEditor::setAddDialogLabel(const QString &addDialogLabel)
 {
-    d->mAddDialogLabel = addDialogLabel.isEmpty() ? i18n("New entry:") : addDialogLabel;
+    d->mAddDialogLabel = addDialogLabel;
 }
 
 void SimpleStringListEditor::slotUp()
