@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "imapaclattributetest.h"
@@ -207,7 +196,7 @@ void ImapAclAttributeTest::testSerializeDeserialize()
     QFETCH(QByteArray, serialized);
     QFETCH(QByteArray, oldSerialized);
 
-    ImapAclAttribute *attr = new ImapAclAttribute();
+    auto *attr = new ImapAclAttribute();
     attr->setRights(rights);
     attr->setMyRights(myRights);
     QCOMPARE(attr->serialized(), serialized);
@@ -233,7 +222,7 @@ void ImapAclAttributeTest::testOldRights()
     acls.insert("second_user@host", KIMAP::Acl::Lookup | KIMAP::Acl::Read);
     acls.insert("third_user@host", KIMAP::Acl::Lookup | KIMAP::Acl::Read);
 
-    ImapAclAttribute *attr = new ImapAclAttribute();
+    auto *attr = new ImapAclAttribute();
     attr->setRights(acls);
 
     ImapAcl oldAcls = acls;
