@@ -1,28 +1,15 @@
 /*
   This file is part of libkdepim.
 
-  Copyright (c) 2002 Helge Deller <deller@gmx.de>
-  Copyright (c) 2002 Lubos Lunak <llunak@suse.cz>
-  Copyright (c) 2001,2003 Carsten Pfeiffer <pfeiffer@kde.org>
-  Copyright (c) 2001 Waldo Bastian <bastian@kde.org>
-  Copyright (c) 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
-  Copyright (c) 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2002 Helge Deller <deller@gmx.de>
+  SPDX-FileCopyrightText: 2002 Lubos Lunak <llunak@suse.cz>
+  SPDX-FileCopyrightText: 2001, 2003 Carsten Pfeiffer <pfeiffer@kde.org>
+  SPDX-FileCopyrightText: 2001 Waldo Bastian <bastian@kde.org>
+  SPDX-FileCopyrightText: 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
+  SPDX-FileCopyrightText: 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "addresseelineedit.h"
@@ -279,7 +266,7 @@ void AddresseeLineEdit::mouseReleaseEvent(QMouseEvent *event)
     if (d->useCompletion()
         && QApplication::clipboard()->supportsSelection()
         && !isReadOnly()
-        && event->button() == Qt::MidButton) {
+        && event->button() == Qt::MiddleButton) {
         d->setSmartPaste(true);
     }
 #endif
@@ -298,9 +285,8 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
         KContacts::Addressee::List list;
         KContacts::VCardDrag::fromMimeData(md, list);
 
-        const KContacts::Addressee::List::ConstIterator end(list.constEnd());
-        for (KContacts::Addressee::List::ConstIterator ait = list.constBegin(); ait != end; ++ait) {
-            insertEmails((*ait).emails());
+        for (const KContacts::Addressee &addr : qAsConst(list)) {
+            insertEmails(addr.emails());
         }
     }
     // Case two: The user dropped a list or Urls.
@@ -331,7 +317,7 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                         dataStream.open(QIODevice::ReadOnly);
                         QString error;
                         if (KContacts::ContactGroupTool::convertFromXml(&dataStream, group, &error)) {
-                            Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(group);
+                            auto *expandJob = new Akonadi::ContactGroupExpandJob(group);
                             connect(expandJob, &Akonadi::ContactGroupExpandJob::result, this, &AddresseeLineEdit::groupExpandResult);
                             expandJob->start();
                         } else {
@@ -425,7 +411,7 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
 
 void AddresseeLineEdit::groupExpandResult(KJob *job)
 {
-    Akonadi::ContactGroupExpandJob *expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
+    auto *expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
 
     if (!expandJob) {
         return;
@@ -434,7 +420,7 @@ void AddresseeLineEdit::groupExpandResult(KJob *job)
     const KContacts::Addressee::List contacts = expandJob->contacts();
     for (const KContacts::Addressee &addressee : contacts) {
         if (d->expandIntern() || text().trimmed().isEmpty()) {
-            insertEmails(QStringList() << addressee.fullEmail());
+            insertEmails({addressee.fullEmail()});
         } else {
             Q_EMIT addAddress(addressee.fullEmail());
         }
@@ -462,8 +448,8 @@ void AddresseeLineEdit::insertEmails(const QStringList &emails)
     QMenu menu(this);
     menu.setTitle(i18n("Select email from contact"));
     menu.setObjectName(QStringLiteral("Addresschooser"));
-    for (QStringList::const_iterator it = emails.constBegin(), end = emails.constEnd(); it != end; ++it) {
-        menu.addAction(*it);
+    for (const QString &email : emails) {
+        menu.addAction(email);
     }
     const QAction *result = menu.exec(QCursor::pos());
     if (!result) {
@@ -502,22 +488,15 @@ void AddresseeLineEdit::addContactGroup(const KContacts::ContactGroup &group, in
     d->addCompletionItem(group.name(), weight, source);
 }
 
-void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight, int source, QString append)
+void AddresseeLineEdit::addContact(const QStringList &emails, const KContacts::Addressee &addr, int weight, int source, QString append)
 {
-    const QStringList emails = AddresseeLineEditManager::self()->cleanupEmailList(addr.emails());
-    if (emails.isEmpty()) {
-        return;
-    }
-    QStringList::ConstIterator it;
     int isPrefEmail = 1; //first in list is preferredEmail
-    QStringList::ConstIterator end(emails.constEnd());
-    for (it = emails.constBegin(); it != end; ++it) {
+    for (const QString &email : emails) {
         //TODO: highlight preferredEmail
-        const QString email((*it));
         const QString givenName = addr.givenName();
         const QString familyName = addr.familyName();
         const QString nickName = addr.nickName();
-        QString fullEmail = addr.fullEmail(email);
+        const QString fullEmail = addr.fullEmail(email);
 
         QString appendix;
 
@@ -558,6 +537,15 @@ void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight,
     }
 }
 
+void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight, int source, const QString &append)
+{
+    const QStringList emails = AddresseeLineEditManager::self()->cleanupEmailList(addr.emails());
+    if (emails.isEmpty()) {
+        return;
+    }
+    addContact(emails, addr, weight, source, append);
+}
+
 #ifndef QT_NO_CONTEXTMENU
 void AddresseeLineEdit::contextMenuEvent(QContextMenuEvent *event)
 {
@@ -635,8 +623,7 @@ void AddresseeLineEdit::loadContacts()
     const QString recentAddressGroupName = i18n("Recent Addresses");
     if (showRecentAddresses()) {
         const QStringList recent
-            = AddresseeLineEditManager::self()->cleanupEmailList(PimCommon::RecentAddresses::self(recentAddressConfig())->addresses());
-        QStringList::ConstIterator it = recent.constBegin();
+            = AddresseeLineEditManager::self()->cleanupRecentAddressEmailList(PimCommon::RecentAddresses::self(recentAddressConfig())->addresses());
         QString name, email;
 
         KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kpimcompletionorder"));
@@ -645,10 +632,12 @@ void AddresseeLineEdit::loadContacts()
         removeCompletionSource(recentAddressGroupName);
         const int idx = addCompletionSource(recentAddressGroupName, weight);
 
-        QStringList::ConstIterator end = recent.constEnd();
-        KContacts::Addressee addr;
-        for (; it != end; ++it) {
-            KEmailAddress::extractEmailAddressAndName(*it, email, name);
+        for (const QString &recentAdr : recent) {
+            KContacts::Addressee addr;
+            KEmailAddress::extractEmailAddressAndName(recentAdr, email, name);
+            if (email.isEmpty()) {
+                continue;
+            }
             name = KEmailAddress::quoteNameIfNecessary(name);
             if (!name.isEmpty() && (name[0] == QLatin1Char('"')) && (name[name.length() - 1] == QLatin1Char('"'))) {
                 name.remove(0, 1);
@@ -656,7 +645,7 @@ void AddresseeLineEdit::loadContacts()
             }
             addr.setNameFromString(name);
             addr.insertEmail(email, true);
-            addContact(addr, weight, idx);
+            addContact({email}, addr, weight, idx);
         }
     } else {
         removeCompletionSource(recentAddressGroupName);
@@ -696,7 +685,7 @@ bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
             const Qt::MouseButtons buttons = mouseEvent->buttons();
             if (event->type() == QEvent::MouseButtonPress
                 || event->type() == QEvent::MouseButtonDblClick
-                || buttons & Qt::LeftButton || buttons & Qt::MidButton
+                || buttons & Qt::LeftButton || buttons & Qt::MiddleButton
                 || buttons & Qt::RightButton) {
                 if (itemIsHeader(item)) {
                     return true; // eat the event, we don't want anything to happen
@@ -716,7 +705,7 @@ bool AddresseeLineEdit::eventFilter(QObject *object, QEvent *event)
 
     if ((object == this)
         && (event->type() == QEvent::ShortcutOverride)) {
-        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        auto *keyEvent = static_cast<QKeyEvent *>(event);
         if (keyEvent->key() == Qt::Key_Up || keyEvent->key() == Qt::Key_Down
             || keyEvent->key() == Qt::Key_Tab) {
             keyEvent->accept();
@@ -899,7 +888,7 @@ void AddresseeLineEdit::slotEditingFinished()
     if (!text().trimmed().isEmpty() && enableAkonadiSearch()) {
         const QStringList addresses = KEmailAddress::splitAddressList(text());
         for (const QString &address : addresses) {
-            Akonadi::ContactGroupSearchJob *job = new Akonadi::ContactGroupSearchJob();
+            auto *job = new Akonadi::ContactGroupSearchJob();
             connect(job, &Akonadi::ContactGroupSearchJob::result, this, &AddresseeLineEdit::slotGroupSearchResult);
             d->mightBeGroupJobsAdd(job);
             job->setQuery(Akonadi::ContactGroupSearchJob::Name, address);
@@ -909,7 +898,7 @@ void AddresseeLineEdit::slotEditingFinished()
 
 void AddresseeLineEdit::slotGroupSearchResult(KJob *job)
 {
-    Akonadi::ContactGroupSearchJob *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
+    auto *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
 
     // Laurent I don't understand why Akonadi::ContactGroupSearchJob send two "result(...)" signal. For the moment
     // avoid to go in this method twice, until I understand it.
@@ -938,7 +927,7 @@ void AddresseeLineEdit::expandGroups()
 
     const KContacts::ContactGroup::List lstGroups = d->groups();
     for (const KContacts::ContactGroup &group : lstGroups) {
-        Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(group);
+        auto *expandJob = new Akonadi::ContactGroupExpandJob(group);
         connect(expandJob, &Akonadi::ContactGroupExpandJob::result, this, &AddresseeLineEdit::groupExpandResult);
         addresses.removeAll(group.name());
         expandJob->start();
