@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
@@ -39,11 +26,10 @@
 using namespace PimCommon;
 BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget *parent)
     : QWidget(parent)
-    , mLimit(500)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
-    QHBoxLayout *searchLayout = new QHBoxLayout;
+    auto *searchLayout = new QHBoxLayout;
     mainLayout->addLayout(searchLayout);
 
     QLabel *lab = new QLabel(i18n("Search email:"), this);
@@ -80,10 +66,10 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     connect(mBlackListWarning, &BlackListBalooEmailWarning::saveChanges, this, &BlackListBalooEmailCompletionWidget::slotSaveChanges);
     mainLayout->addWidget(mBlackListWarning);
 
-    QHBoxLayout *searchLineLayout = new QHBoxLayout;
+    auto *searchLineLayout = new QHBoxLayout;
     mainLayout->addLayout(searchLineLayout);
 
-    QHBoxLayout *selectElementLayout = new QHBoxLayout;
+    auto *selectElementLayout = new QHBoxLayout;
     searchLineLayout->addLayout(selectElementLayout);
 
     mSelectButton = new QPushButton(i18n("&Select"), this);
@@ -119,7 +105,7 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     searchLineLayout->addWidget(mNumberOfEmailsFound);
     searchLineLayout->addWidget(mSearchInResultLineEdit);
 
-    QHBoxLayout *excludeDomainLayout = new QHBoxLayout;
+    auto *excludeDomainLayout = new QHBoxLayout;
     excludeDomainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addLayout(excludeDomainLayout);
 
@@ -193,7 +179,7 @@ void BlackListBalooEmailCompletionWidget::slotSearch()
     const QString searchEmail = mSearchLineEdit->text().trimmed();
     if (searchEmail.length() > 2) {
         mSearchInResultLineEdit->clear();
-        PimCommon::BlackListBalooEmailSearchJob *job = new PimCommon::BlackListBalooEmailSearchJob(this);
+        auto *job = new PimCommon::BlackListBalooEmailSearchJob(this);
         job->setSearchEmail(searchEmail);
         job->setLimit(mLimit);
         connect(job, &BlackListBalooEmailSearchJob::emailsFound, this, &BlackListBalooEmailCompletionWidget::slotEmailFound);
