@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "checkedcollectionwidget.h"
@@ -51,11 +39,11 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     : QWidget(parent)
     , d(new PimCommon::CheckedCollectionWidgetPrivate)
 {
-    QVBoxLayout *vbox = new QVBoxLayout(this);
+    auto *vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0, 0, 0, 0);
 
     // Create a new change recorder.
-    Akonadi::Monitor *monitor = new Akonadi::Monitor(this);
+    auto *monitor = new Akonadi::Monitor(this);
     monitor->setObjectName(QStringLiteral("CheckedCollectionWidgetMonitor"));
     monitor->fetchCollection(true);
     monitor->setAllMonitored(true);
@@ -67,9 +55,9 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     // Set the model to show only collections, not items.
     d->mEntityTreeModel->setItemPopulationStrategy(Akonadi::EntityTreeModel::NoItemPopulation);
 
-    Akonadi::CollectionFilterProxyModel *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
+    auto *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
     mimeTypeProxy->setExcludeVirtualCollections(true);
-    mimeTypeProxy->addMimeTypeFilters(QStringList() << mimetype);
+    mimeTypeProxy->addMimeTypeFilters({mimetype});
     mimeTypeProxy->setSourceModel(d->mEntityTreeModel);
 
     // Create the Check proxy model.
@@ -82,7 +70,7 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     d->mCollectionFilter->setSourceModel(d->mCheckProxy);
     d->mCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
-    QLineEdit *searchLine = new QLineEdit(this);
+    auto *searchLine = new QLineEdit(this);
     searchLine->setPlaceholderText(i18n("Search..."));
     searchLine->setClearButtonEnabled(true);
     connect(searchLine, &QLineEdit::textChanged, this, &CheckedCollectionWidget::slotSetCollectionFilter);
